@@ -73,6 +73,8 @@ struct _LauncherIconPrivate
   guint32 initial_motion_time;
   gint   initial_click_x;
   gint   initial_click_y;
+
+  gboolean can_fav;
 };
 
 static inline gint
@@ -238,6 +240,10 @@ show_menu (LauncherIcon *icon, ClutterButtonEvent *event)
     gtk_widget_show (item);
     g_signal_connect (item, "activate", G_CALLBACK (remove_app), icon);
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+  }
+  else if (!priv->can_fav)
+  {
+
   }
   else
   {
@@ -388,6 +394,7 @@ launcher_icon_set_application (LauncherIcon            *icon,
   priv = icon->priv;
 
   priv->app = application;
+  priv->can_fav = application->can_fav;
 
   /* Icon */
   pixbuf = launcher_menu_application_get_icon (application);
@@ -446,9 +453,10 @@ launcher_icon_set_application (LauncherIcon            *icon,
   g_signal_connect (icon, "leave-event",
                     G_CALLBACK (on_leave), icon);
   clutter_actor_set_reactive (priv->texture, TRUE);
-  g_signal_connect (icon, "motion-event", 
+  
+  if (application->can_fav)
+    g_signal_connect (icon, "motion-event", 
                     G_CALLBACK (on_motion), icon);
- 
 }
 
 void 
